pub enum BrakingMode {
Normal,
Precise,
}Expand description
When FlightMode is Braking, the agent can use different braking modes to control the amount of overshoot and oscillation.
Variants
Normal
Oscillation around the target position is acceptable, with slow damping. This mode is useful for when the entity is not expected to fully stop at the target position, and arrival near the target position is more important than precision.
Precise
Prefer faster damping of position error, reducing overshoot and oscillation around the target position. This mode is useful for when the entity is expected to fully stop at the target and precision is most important.