pub enum FlightMode {
Braking(BrakingMode),
FlyThrough,
}Expand description
The desired flight behavior when an entity is approaching a target position.
Variants
Braking(BrakingMode)
The agent should cause the entity to decelerate and stop at the target position.
FlyThrough
The agent should cause the entity to fly to and through the target position without slowing.